surrogate gradients
-------------------
.. currentmodule:: sinabs.activation
    
Heaviside
^^^^^^^^^
.. autoclass:: Heaviside
    :members:

MultiGaussian
^^^^^^^^^^^^^
.. autoclass:: MultiGaussian
    :members:

SingleExponential
^^^^^^^^^^^^^^^^^
.. autoclass:: SingleExponential
    :members:
